==> darklua-0.4.1.crate: darklua-0.4.1/src/rules/rename_variables/globals.rs <==
pub const KEYWORDS: [&'static str; 21] = [
    "and",
    "break",
    "do",
    "else",
    "elseif",
    "end",
    "false",
    "for",
    "function",
    "if",
    "in",
    "local",
    "nil",
    "not",
    "or",
    "repeat",
    "return",
    "then",
    "true",
    "until",
    "while",
];

pub const DEFAULT: [&'static str; 40] = [
    "arg",
    "assert",
    "collectgarbage",
    "coroutine",
    "debug",
    "dofile",
    "error",
    "gcinfo",
    "getfenv",
    "getmetatable",
    "io",
    "ipairs",
    "load",
    "loadfile",
    "loadstring",
    "math",
    "module",
    "newproxy",
    "next",
    "os",
    "package",
    "pairs",
    "pcall",
    "print",
    "rawequal",
    "rawget",
    "rawset",
    "require",
    "select",
    "setfenv",
    "setmetatable",
    "string",
    "table",
    "tonumber",
    "tostring",
    "type",
    "unpack",
    "xpcall",
    "_G",
    "_VERSION",
];

pub const ROBLOX: [&'static str; 55] = [
    "Axes",
    "bit32",
    "BrickColor",
    "CellId",
    "ColorSequence",
    "ColorSequenceKeypoint",
    "Color3",
    "CFrame",
    "DateTime",
    "DebuggerManager",
    "delay",
    "DockWidgetPluginGuiInfo",
    "elapsedTime",
    "Enum",
    "Faces",
    "Instance",
    "LoadLibrary",
    "game",
    "NumberRange",
    "NumberSequence",
    "NumberSequenceKeypoint",
    "PathWaypoint",
    "PhysicalProperties",
    "plugin",
    "PluginDrag",
    "PluginManager",
    "printidentity",
    "Random",
    "Ray",
    "RaycastParams",
    "Rect",
    "Region3",
    "Region3int16",
    "script",
    "settings",
    "shared",
    "stats",
    "spawn",
    "tick",
    "time",
    "TweenInfo",
    "typeof",
    "UDim",
    "UDim2",
    "UserSettings",
    "utf8",
    "Vector2",
    "Vector2int16",
    "Vector3",
    "Vector3int16",
    "version",
    "wait",
    "warn",
    "workspace",
    "ypcall",
];

==> darklua-0.6.0.crate: darklua-0.6.0/src/rules/rename_variables/globals.rs <==
pub const KEYWORDS: [&str; 21] = [
    "and", "break", "do", "else", "elseif", "end", "false", "for", "function", "if", "in", "local",
    "nil", "not", "or", "repeat", "return", "then", "true", "until", "while",
];

pub const DEFAULT: [&str; 40] = [
    "arg",
    "assert",
    "collectgarbage",
    "coroutine",
    "debug",
    "dofile",
    "error",
    "gcinfo",
    "getfenv",
    "getmetatable",
    "io",
    "ipairs",
    "load",
    "loadfile",
    "loadstring",
    "math",
    "module",
    "newproxy",
    "next",
    "os",
    "package",
    "pairs",
    "pcall",
    "print",
    "rawequal",
    "rawget",
    "rawset",
    "require",
    "select",
    "setfenv",
    "setmetatable",
    "string",
    "table",
    "tonumber",
    "tostring",
    "type",
    "unpack",
    "xpcall",
    "_G",
    "_VERSION",
];

pub const ROBLOX: [&str; 55] = [
    "Axes",
    "bit32",
    "BrickColor",
    "CellId",
    "ColorSequence",
    "ColorSequenceKeypoint",
    "Color3",
    "CFrame",
    "DateTime",
    "DebuggerManager",
    "delay",
    "DockWidgetPluginGuiInfo",
    "elapsedTime",
    "Enum",
    "Faces",
    "Instance",
    "LoadLibrary",
    "game",
    "NumberRange",
    "NumberSequence",
    "NumberSequenceKeypoint",
    "PathWaypoint",
    "PhysicalProperties",
    "plugin",
    "PluginDrag",
    "PluginManager",
    "printidentity",
    "Random",
    "Ray",
    "RaycastParams",
    "Rect",
    "Region3",
    "Region3int16",
    "script",
    "settings",
    "shared",
    "stats",
    "spawn",
    "tick",
    "time",
    "TweenInfo",
    "typeof",
    "UDim",
    "UDim2",
    "UserSettings",
    "utf8",
    "Vector2",
    "Vector2int16",
    "Vector3",
    "Vector3int16",
    "version",
    "wait",
    "warn",
    "workspace",
    "ypcall",
];
